#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys
import json
import logging, logging.handlers
import uuid
import time

from flask import Flask, abort, request
from flask.ext.autodoc import Autodoc

import psycopg2
import graypy
import pika


LEVEL = {
    "DEBUG": logging.DEBUG,
    "INFO": logging.INFO,
    "WARNING": logging.WARNING,
    "ERROR": logging.ERROR,
    "CRITICAL":logging.CRITICAL,
}

EX_IN = os.environ['EX_IN']
MQ_user = os.environ['MQ_USER']
MQ_password = os.environ['MQ_PASSWORD']
MQ_host = os.environ['MQ_HOST']
LogLevel = LEVEL[os.environ['LOG_LEVEL']]
LogFilename = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'log', os.environ['LOG_FILENAME'])
LogMaxbytes = int(os.environ['LOG_MAXBYTES'])
LogBackcount = int(os.environ['LOG_BACKCOUNT'])
LogGraylogMq = os.environ['LOG_GRAYLOG_MQ']
LogGraylogEx = os.environ['LOG_GRAYLOG_EX']
HOST = os.environ['HOST']
PORT = int(os.environ['PORT'])
PG = "dbname=postgres user=postgres host='postgres' password='postgres'"


app = Flask(__name__)
app.doc = Autodoc(app)

from functools import wraps
from flask import g, request, redirect, url_for

def trace(f):
    @wraps(f)
    def decorated_function(*args, **kwargs):
        start_time = time.time()  
        res = f(*args, **kwargs)
        interval = time.time() - start_time 
        app.logger.debug('call %s with %s and %s time: %s' % (f.__name__, args, kwargs, interval))
        return res
    return decorated_function


app.trace = trace


############################ Route #############################################

@app.route("/ws/set", methods = ['POST'])
@app.doc.doc()
@app.trace
def url_set():
    """ 
    Fonction set
    enregistre des inscriptions
    
    input au format json methode POST comportant les données de l'inscription

    """
    data = json.loads(request.data.decode())
    id = data['id']
    conn = psycopg2.connect(PG)
    cur = conn.cursor()
    cur.execute("INSERT INTO play (id) VALUES (%s)",  (id,))
    conn.commit()
    cur.close()
    conn.close()
    app.logger.info('insert play %s' % id)
    connection = pika.BlockingConnection(pika.ConnectionParameters(host=MQ_host,credentials = pika.PlainCredentials(MQ_user, MQ_password)))
    channel = connection.channel()
    channel.basic_publish(exchange=EX_IN,
                          routing_key='',
                          body=json.dumps( {'id':id}))
    connection.close()
    app.logger.info('insert msg for %s' % id)
    return json.dumps({'msg':'ok'})


@app.route('/ws/documentation')
def documentation():
    return app.doc.html()


if __name__ == "__main__":
    if not app.debug:
        app.logger.setLevel(LogLevel)
        file_handler = logging.handlers.RotatingFileHandler(LogFilename,
                            maxBytes=LogMaxbytes,
                            backupCount=LogBackcount)
        file_handler.setLevel(LogLevel)
        app.logger.addHandler(file_handler) 
        graylog_handler = graypy.GELFRabbitHandler(LogGraylogMq, LogGraylogEx)
        graylog_handler.setLevel(LogLevel)
        app.logger.addHandler(graylog_handler)
    app.run(host = HOST,
            port = PORT,
            threaded=True)


