#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import logging
import json

import pika
import graypy
import requests


LEVEL = {
    "DEBUG": logging.DEBUG,
    "INFO": logging.INFO,
    "WARNING": logging.WARNING,
    "ERROR": logging.ERROR,
    "CRITICAL":logging.CRITICAL,
}

QueueIn = os.environ['QUEUE_IN']
MQ_user = os.environ['MQ_USER']
MQ_password = os.environ['MQ_PASSWORD']
MQ_host = os.environ['MQ_HOST']
LogLevel = LEVEL[os.environ['LOG_LEVEL']]
LogFilename = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'log', os.environ['LOG_FILENAME'])
LogMaxbytes = int(os.environ['LOG_MAXBYTES'])
LogBackcount = int(os.environ['LOG_BACKCOUNT'])
LogGraylogMq = os.environ['LOG_GRAYLOG_MQ']
LogGraylogEx = os.environ['LOG_GRAYLOG_EX']
ServiceHost = os.environ['SERVICE_HOST']

my_logger = logging.getLogger('MyLogger')
my_logger.setLevel(LogLevel)
file_handler = logging.handlers.RotatingFileHandler(LogFilename, 
                    maxBytes=LogMaxbytes,
                    backupCount=LogBackcount)
file_handler.setLevel(LogLevel)
my_logger.addHandler(file_handler) 
graylog_handler = graypy.GELFRabbitHandler(LogGraylogMq, LogGraylogEx)
graylog_handler.setLevel(LogLevel)
my_logger.addHandler(graylog_handler)


connection = pika.BlockingConnection(
    pika.ConnectionParameters(
        host=MQ_host,
        credentials = pika.PlainCredentials(MQ_user , MQ_password)
        )
    )
channel = connection.channel()

def callback(ch, method, properties, body):
    my_logger.debug("recept %s" % body)
    val = json.loads(body.decode('utf-8'))
    id = val['id']
    r = requests.post("http://%s/ws/set" % ServiceHost, data=body)
    my_logger.debug("requests post on http://%s/ws/play value %s for id %s" % (ServiceHost, r.status_code, id))

channel.basic_consume(callback,
                  queue=QueueIn,
                  no_ack=True)
channel.start_consuming()
